import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import java.lang.reflect.Method;

/**
 * Embedded demo window class.
 */
public class DemoFrame extends JFrame
{
  JLabel statusBar = new JLabel();
  JPanel mainPanel = new JPanel();
  ImageIcon icon = new ImageIcon();
  JLabel iconLabel = new JLabel();
  ImageContainer parent;

  /**
   * Constructs a DemoFrame and starts the demo.
   * @param parent The demo object.
   */
  public DemoFrame(ImageContainer parent)
  {
    this.parent = parent;
    enableEvents(AWTEvent.WINDOW_EVENT_MASK);
    try
    {
      init();
      runDemo();
    }
    catch(Exception e)
    {
      e.printStackTrace();
    }
  } //DemoFrame

  /**
   * GUI init.
   */
  private void init() throws Exception
  {
    this.getContentPane().setLayout(new BorderLayout());
    this.setSize(new Dimension(320, 240));
    this.setTitle("ImageContainer");

    statusBar.setBorder(BorderFactory.createEtchedBorder());
    statusBar.setText("Ready");

    mainPanel.setLayout(new BorderLayout());
    mainPanel.add(iconLabel, BorderLayout.CENTER);

    this.getContentPane().add(mainPanel, BorderLayout.CENTER);
    this.getContentPane().add(statusBar, BorderLayout.SOUTH);
  } //init

  /**
   * Runs the demo.
   */
  private void runDemo() throws Exception
  {
    statusBar.setText("Created " + parent);
    byte[] rawImage = new byte[320*240*3];
    Object[] args = new Object[1];
    try
    {
      Class[] params = new Class[1];
      params[0] = rawImage.getClass();
      Method processRawImage = parent.getClass().getMethod("processRawImage", params);
      statusBar.setText("Method processRawImage(byte[]) found");
      args[0] = rawImage;
      Image image = (Image) processRawImage.invoke(parent, args);
      icon.setImage(image);
      iconLabel.setIcon(icon);
    }
    catch (NoSuchMethodException e)
    {
      statusBar.setText("Method processRawImage(byte[]) not found");
    }
  } //runDemo

  /**
   * Overridden event processing to link close event to button.
   * @param e The window event.
   */
  protected void processWindowEvent(WindowEvent e)
  {
    super.processWindowEvent(e);
    if(e.getID() == WindowEvent.WINDOW_CLOSING)
    {
      System.exit(0);
    }
  } //processWindowEvent
} //class DemoFrame

/**
 * Constructs an ImageContainer and starts the demo.
 */
public ImageContainer()
{
  DemoFrame frame = new DemoFrame(this);
  frame.validate();
  frame.setVisible(true);
} //ImageContainer

/**
 * Main method.
 * @param args Application arguments array.
 */
public static void main(String[] args)
{
  ImageContainer img = new ImageContainer();
} //main
