import java.util.Date;
import java.util.Calendar;
import java.text.Format;
import java.util.GregorianCalendar;
import java.io.Serializable;
import java.text.SimpleDateFormat;
/**
 * Time/date class for SEESCOA.
 TimeData stores a date/time in a precision of milliseconds.
@author Miro Casanova
@author Dennis Wagelaar
@version 23 October 2002
 */
public class TimeData implements Serializable {
  private GregorianCalendar calendar= new GregorianCalendar();
  private Format time= new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
  private int milliSec;
  private Format timestamp= new SimpleDateFormat("yyyyMMddHHmmss");
  /**
   * Constructs a TimeData and initialises to the current time.
   * @author Miro Casanova
   * @author Dennis Wagelaar
   */
  public TimeData() {
    setMilliSec(calendar.get(Calendar.MILLISECOND));
  } //TimeData
  /**
   * Constructs a TimeData.
   * @param time The time data to copy from
   * @author Dennis Wagelaar
   */
  public TimeData(TimeData time) {
    this.setTime(time);
  } //TimeData
  /**
   * Constructs a TimeData.
   * @param year The year (e.g. 2002)
   * @param month The month (e.g. 12)
   * @param day The day of the month (e.g. 31)
   * @param hour The hour (e.g. 23)
   * @param minute The minute (e.g. 59)
   * @param second The second (e.g. 59)
   * @param msecond The amount of milliseconds (e.g. 999)
   * @author Miro Casanova
   * @author Dennis Wagelaar
   */
  public TimeData(int year, int month, int day, int hour, int minute, int second,
    int msecond) {
    // Month value is 0-based
    calendar = new GregorianCalendar(year, month - 1, day, hour, minute, second);
    setMilliSec(msecond);
  } //TimeData
  /**
   * Gets the formatted object as a String.
  @return The formatted object.
  @author Dennis Wagelaar
   */
  public String getTimestamp() {
    return this.timestamp.format(this.getTimeAsDate());
  }
  /**
   * Sets the property value
   */
  public void setMilliSec(int milliSec) {
    this.milliSec = milliSec;
  }
  /**
   * Gets the property value
   */
  public int getMilliSec() {
    return this.milliSec;
  }
  /**
   * Gets the formatted object as a String.
  @return The formatted object.
  @author Dennis Wagelaar
   */
  public String getTime() {
    return this.time.format(this.getTimeAsDate());
  }
  /**
   * Sets the time as a Date object.
   */
  public void setTimeAsDate(Date aDate) {
    calendar.setTime(aDate);
  }
  /**
   * Gets the time as a Date object.
   */
  public Date getTimeAsDate() {
    return calendar.getTime();
  }
  /**
   * Sets the time attribute.
  @param time The date/time
  @author Dennis Wagelaar
   */
  public void setTime(TimeData timeDataVal) {
    this.setTimeAsDate(timeDataVal.getTimeAsDate());
    this.setMilliSec(timeDataVal.getMilliSec());
  }
}