/**
 * Title:        CoCompose
 * Copyright:    Copyright (c) 2002, 2003
 * Author:       Dennis Wagelaar
 * Organisation: University of Twente, Vrije Universiteit Brussel
 * Description:  CoCompose Design Language Tool
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  (See the file "COPYING" that is included with this source distribution.)
 */

package translate;

import EDU.utwente.CoCompose.lang.*;
import EDU.utwente.CoCompose.util.*;

/**
 * Applies post-processing for the SEESCOA java-based component language after
 * the concept forms have been determined.
 *
 * @author Dennis Wagelaar
 * @version 0.1.06, 8 January 2003
 */

public class SEESCOAFormsPostproc extends JavaFormsPostproc
{
  //////////////////////////////////////////////////////////////////////////////
  // Constructors
  //////////////////////////////////////////////////////////////////////////////

  /**
   * Constructs a SEESCOAFormsPostproc.
   */
  public SEESCOAFormsPostproc()
  {
    lang = "SEESCOA";
  } //SEESCOAFormsPostproc

  //////////////////////////////////////////////////////////////////////////////
  // Public methods
  //////////////////////////////////////////////////////////////////////////////

  /**
   * Adapts the concept's name to the Java naming convention corresponding
   * to the concept's form.<BR>
   * PRE: The concept's form must have been determined.
   *
   * @param concept The concept to adapt the name of.
   * @throws CoComposeException if the concept's name could not be adapted.
   */
  public void visitConcept(Concept concept) throws CoComposeException
  {
    String form;

    if (log != null)
    {
      log.log("Adapting concept name for " + concept.getName());
      log.incLogLevel();
    }
    try
    {
      // retrieve form
      form = concept.getForm();
      if (form.length() == 0)
        throw new CoComposeException("Form has not been determined for " +
          concept.getName(), concept);
      // adapt depending on form
      if (form.endsWith("Class") || form.equals("Interface") ||
          form.equals("Message") || form.equals("Port"))
      { // start with uppercase character
        concept.setName(ucfirst(concept.getName()));
      }
      else if (form.endsWith("Method") || form.equals("Instance"))
      { // start with lowercase character
        concept.setName(lcfirst(concept.getName()));
      }
    }
    finally
    {
      if (log != null)
        log.decLogLevel();
    }
  } //visitConcept
} //class SEESCOAFormsPostproc